app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("testWrongEnvironmentFunction")

app$setInputs(objectiveFunction = "rEnv")
app$setInputs(funName = "unknownFunctionForTestingPurpose")
app$setInputs(addDimension = "click")
app$setInputs(addDimension = "click")
app$setInputs(dimensionAmount3 = 2)
app$setInputs(lowerBound3 = -4)
app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runSpotIter = "click")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(funName = "funBranin")
app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runSpotIter = "click")
Sys.sleep(5)
app$snapshot(list(output = "resultTable"))
